@@ -16,7 +16,7 @@ use Ref::Util;
 use HTML::Show;
 use UUID::Tiny ':std';
 
-our $VERSION = '0.009';    # VERSION
+our $VERSION = '0.010';    # VERSION
 
 # ABSTRACT: Generate html/javascript charts from perl data using javascript library plotly.js
 
@@ -124,7 +124,7 @@ Chart::Plotly - Generate html/javascript charts from perl data using javascript
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -177,6 +177,8 @@ version 0.009
 Generate html/javascript charts from perl data using javascript library plotly.js. The result
 is a file that you could see in your favourite browser.
 
+=for markdown [![Build Status](https://travis-ci.org/pablrod/p5-Chart-Plotly.png?branch=master)](https://travis-ci.org/pablrod/p5-Chart-Plotly)
+
 Example screenshot of plot generated with examples/anscombe.pl:
 
 =for HTML <p>
@@ -252,4 +254,10 @@ This is free software, licensed under:
 
   The MIT (X11) License
 
+=head1 CONTRIBUTOR
+
+=for stopwords weatherwax
+
+weatherwax <s.g.lobo@hotmail.com>
+
 =cut
