@@ -5,7 +5,7 @@ use Chart::Plotly::Trace::Attribute::Error_x;
 use Chart::Plotly::Trace::Attribute::Error_y;
 use Chart::Plotly::Trace::Attribute::Marker;
 
-our $VERSION = '0.009';    # VERSION
+our $VERSION = '0.010';    # VERSION
 
 sub TO_JSON {
     my $self = shift;
@@ -69,7 +69,7 @@ has t => ( is            => 'rw',
 
 has text => (
     is  => 'rw',
-    isa => "Str",
+    isa => "Maybe[ArrayRef]|Str",
     documentation =>
       "Sets text elements associated with each (x,y) pair. If a single string, the same string appears over all the data points. If an array of string, the items are mapped in order to the this trace's (x,y) coordinates.",
 );
@@ -133,16 +133,28 @@ Chart::Plotly::Trace::Bar
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
-	use HTML::Show;
-	use Chart::Plotly;
-	use Chart::Plotly::Trace::Bar;
-	my $bar = Chart::Plotly::Trace::Bar->new(x => [1 .. 5], y => [1 .. 5]);
-	
-	HTML::Show::show(Chart::Plotly::render_full_html(data => [$bar]));
+ use Chart::Plotly;
+ use Chart::Plotly::Trace::Bar;
+ use Chart::Plotly::Plot;
+ my $x = [ "apples", "bananas", "cherries" ];
+ my $sample1 = Chart::Plotly::Trace::Bar->new( x    => $x,
+                                               y    => [ map { int( rand() * 10 ) } ( 1 .. ( scalar(@$x) ) ) ],
+                                               name => "sample1"
+ );
+ my $sample2 = Chart::Plotly::Trace::Bar->new( x    => $x,
+                                               y    => [ map { int( rand() * 10 ) } ( 1 .. ( scalar(@$x) ) ) ],
+                                               name => "sample2"
+ );
+ my $sample3 = Chart::Plotly::Trace::Bar->new( x    => $x,
+                                               y    => [ map { int( rand() * 10 ) } ( 1 .. ( scalar(@$x) ) ) ],
+                                               name => "sample3"
+ );
+ my $plot = Chart::Plotly::Plot->new( traces => [ $sample1, $sample2, $sample3 ], layout => { barmode => 'group' } );
+ Chart::Plotly::show_plot($plot);
 
 =head1 DESCRIPTION
 
