@@ -5,7 +5,7 @@ use Chart::Plotly::Trace::Attribute::Colorbar;
 use Chart::Plotly::Trace::Attribute::Contours;
 use Chart::Plotly::Trace::Attribute::Line;
 
-our $VERSION = '0.009';    # VERSION
+our $VERSION = '0.010';    # VERSION
 
 sub TO_JSON {
     my $self = shift;
@@ -160,16 +160,26 @@ Chart::Plotly::Trace::Contour
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
-	use HTML::Show;
-	use Chart::Plotly;
-	use Chart::Plotly::Trace::Contour;
-	my $contour = Chart::Plotly::Trace::Contour->new(x => [1 .. 5], y => [1 .. 5]);
-	
-	HTML::Show::show(Chart::Plotly::render_full_html(data => [$contour]));
+ use Chart::Plotly qw(show_plot);
+ use Chart::Plotly::Trace::Contour;
+ use English qw(-no_match_vars);
+ 
+ my $contour = Chart::Plotly::Trace::Contour->new(
+     x => [ 0 .. 10 ],
+     y => [ 0 .. 10 ],
+     z => [
+         map {
+             my $y = $ARG;
+             [ map { $ARG * $ARG + $y * $y } ( 0 .. 10 ) ]
+         } ( 0 .. 10 )
+     ]
+ );
+ 
+ show_plot( [$contour] );
 
 =head1 DESCRIPTION
 
