@@ -3,7 +3,7 @@ use Moose;
 
 use Chart::Plotly::Trace::Attribute::Colorbar;
 
-our $VERSION = '0.009';    # VERSION
+our $VERSION = '0.010';    # VERSION
 
 sub TO_JSON {
     my $self = shift;
@@ -133,16 +133,26 @@ Chart::Plotly::Trace::Heatmapgl
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
-	use HTML::Show;
-	use Chart::Plotly;
-	use Chart::Plotly::Trace::Heatmapgl;
-	my $heatmapgl = Chart::Plotly::Trace::Heatmapgl->new(x => [1 .. 5], y => [1 .. 5]);
-	
-	HTML::Show::show(Chart::Plotly::render_full_html(data => [$heatmapgl]));
+ use Chart::Plotly qw(show_plot);
+ use Chart::Plotly::Trace::Heatmapgl;
+ use English qw(-no_match_vars);
+ 
+ my $heatmap = Chart::Plotly::Trace::Heatmapgl->new(
+     x => [ 0 .. 10 ],
+     y => [ 0 .. 10 ],
+     z => [
+         map {
+             my $y = $ARG;
+             [ map { $ARG * $ARG + $y * $y } ( 0 .. 10 ) ]
+         } ( 0 .. 10 )
+     ]
+ );
+ 
+ show_plot( [$heatmap] );
 
 =head1 DESCRIPTION
 
