@@ -7,7 +7,7 @@ use Chart::Plotly::Trace::Attribute::Marker;
 use Chart::Plotly::Trace::Attribute::Xbins;
 use Chart::Plotly::Trace::Attribute::Ybins;
 
-our $VERSION = '0.009';    # VERSION
+our $VERSION = '0.010';    # VERSION
 
 sub TO_JSON {
     my $self = shift;
@@ -73,7 +73,7 @@ has orientation => (
 
 has text => (
     is  => 'rw',
-    isa => "Str",
+    isa => "Maybe[ArrayRef]|Str",
     documentation =>
       "Sets text elements associated with each (x,y) pair. If a single string, the same string appears over all the data points. If an array of string, the items are mapped in order to the this trace's (x,y) coordinates.",
 );
@@ -115,16 +115,16 @@ Chart::Plotly::Trace::Histogram
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
-	use HTML::Show;
-	use Chart::Plotly;
-	use Chart::Plotly::Trace::Histogram;
-	my $histogram = Chart::Plotly::Trace::Histogram->new(x => [1 .. 5], y => [1 .. 5]);
-	
-	HTML::Show::show(Chart::Plotly::render_full_html(data => [$histogram]));
+ use HTML::Show;
+ use Chart::Plotly;
+ use Chart::Plotly::Trace::Histogram;
+ my $histogram = Chart::Plotly::Trace::Histogram->new( x => [ map { int( 10 * rand() ) } ( 1 .. 500 ) ] );
+ 
+ HTML::Show::show( Chart::Plotly::render_full_html( data => [$histogram] ) );
 
 =head1 DESCRIPTION
 
