@@ -6,7 +6,7 @@ use Chart::Plotly::Trace::Attribute::Marker;
 use Chart::Plotly::Trace::Attribute::Xbins;
 use Chart::Plotly::Trace::Attribute::Ybins;
 
-our $VERSION = '0.009';    # VERSION
+our $VERSION = '0.010';    # VERSION
 
 sub TO_JSON {
     my $self = shift;
@@ -152,16 +152,17 @@ Chart::Plotly::Trace::Histogram2d
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
-	use HTML::Show;
-	use Chart::Plotly;
-	use Chart::Plotly::Trace::Histogram2d;
-	my $histogram2d = Chart::Plotly::Trace::Histogram2d->new(x => [1 .. 5], y => [1 .. 5]);
-	
-	HTML::Show::show(Chart::Plotly::render_full_html(data => [$histogram2d]));
+ use HTML::Show;
+ use Chart::Plotly;
+ use Chart::Plotly::Trace::Histogram2d;
+ my $histogram2d = Chart::Plotly::Trace::Histogram2d->new( x => [ map { int( 10 * rand() ) } ( 1 .. 500 ) ],
+                                                           y => [ map { int( 10 * rand() ) } ( 1 .. 500 ) ] );
+ 
+ HTML::Show::show( Chart::Plotly::render_full_html( data => [$histogram2d] ) );
 
 =head1 DESCRIPTION
 
