@@ -8,7 +8,7 @@ use Chart::Plotly::Trace::Attribute::Marker;
 use Chart::Plotly::Trace::Attribute::Xbins;
 use Chart::Plotly::Trace::Attribute::Ybins;
 
-our $VERSION = '0.009';    # VERSION
+our $VERSION = '0.010';    # VERSION
 
 sub TO_JSON {
     my $self = shift;
@@ -160,16 +160,18 @@ Chart::Plotly::Trace::Histogram2dcontour
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
-	use HTML::Show;
-	use Chart::Plotly;
-	use Chart::Plotly::Trace::Histogram2dcontour;
-	my $histogram2dcontour = Chart::Plotly::Trace::Histogram2dcontour->new(x => [1 .. 5], y => [1 .. 5]);
-	
-	HTML::Show::show(Chart::Plotly::render_full_html(data => [$histogram2dcontour]));
+ use HTML::Show;
+ use Chart::Plotly;
+ use Chart::Plotly::Trace::Histogram2dcontour;
+ my $histogram2dcontour =
+   Chart::Plotly::Trace::Histogram2dcontour->new( x => [ map { int( 10 * rand() ) } ( 1 .. 500 ) ],
+                                                  y => [ map { int( 10 * rand() ) } ( 1 .. 500 ) ] );
+ 
+ HTML::Show::show( Chart::Plotly::render_full_html( data => [$histogram2dcontour] ) );
 
 =head1 DESCRIPTION
 
