@@ -6,7 +6,7 @@ use Chart::Plotly::Trace::Attribute::Contour;
 use Chart::Plotly::Trace::Attribute::Lighting;
 use Chart::Plotly::Trace::Attribute::Lightposition;
 
-our $VERSION = '0.009';    # VERSION
+our $VERSION = '0.010';    # VERSION
 
 sub TO_JSON {
     my $self = shift;
@@ -143,16 +143,25 @@ Chart::Plotly::Trace::Mesh3d
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
-	use HTML::Show;
-	use Chart::Plotly;
-	use Chart::Plotly::Trace::Mesh3d;
-	my $mesh3d = Chart::Plotly::Trace::Mesh3d->new(x => [1 .. 5], y => [1 .. 5]);
-	
-	HTML::Show::show(Chart::Plotly::render_full_html(data => [$mesh3d]));
+ use Chart::Plotly qw(show_plot);
+ use Chart::Plotly::Trace::Mesh3d;
+ use List::Flatten;
+ use List::MoreUtils qw/pairwise/;
+ use English qw(-no_match_vars);
+ 
+ my @x = flat map { [ 0 .. 10 ] } ( 0 .. 10 );
+ my @y = flat map {
+     my $y = $ARG;
+     map { $y } ( 0 .. 10 )
+ } ( 0 .. 10 );
+ my @z = pairwise { $a * $a + $b * $b } @x, @y;
+ my $mesh3d = Chart::Plotly::Trace::Mesh3d->new( x => \@x, y => \@y, z => \@z );
+ 
+ show_plot( [$mesh3d] );
 
 =head1 DESCRIPTION
 
