@@ -4,7 +4,7 @@ use Moose;
 use Chart::Plotly::Trace::Attribute::Domain;
 use Chart::Plotly::Trace::Attribute::Marker;
 
-our $VERSION = '0.009';    # VERSION
+our $VERSION = '0.010';    # VERSION
 
 sub TO_JSON {
     my $self = shift;
@@ -120,16 +120,17 @@ Chart::Plotly::Trace::Pie
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
-	use HTML::Show;
-	use Chart::Plotly;
-	use Chart::Plotly::Trace::Pie;
-	my $pie = Chart::Plotly::Trace::Pie->new(x => [1 .. 5], y => [1 .. 5]);
-	
-	HTML::Show::show(Chart::Plotly::render_full_html(data => [$pie]));
+ use HTML::Show;
+ use Chart::Plotly;
+ use Chart::Plotly::Trace::Pie;
+ my @labels = ( "ants", "bees", "crickets", "dragonflies", "earwigs" );
+ my $pie = Chart::Plotly::Trace::Pie->new( labels => \@labels, values => [ map { int( rand() * 10 ) } @labels ] );
+ 
+ HTML::Show::show( Chart::Plotly::render_full_html( data => [$pie] ) );
 
 =head1 DESCRIPTION
 
