@@ -8,7 +8,7 @@ use Chart::Plotly::Trace::Attribute::Line;
 use Chart::Plotly::Trace::Attribute::Marker;
 use Chart::Plotly::Trace::Attribute::Projection;
 
-our $VERSION = '0.009';    # VERSION
+our $VERSION = '0.010';    # VERSION
 
 sub TO_JSON {
     my $self = shift;
@@ -61,7 +61,7 @@ has surfacecolor => ( is            => 'rw',
 
 has text => (
     is  => 'rw',
-    isa => "Str",
+    isa => "Maybe[ArrayRef]|Str",
     documentation =>
       "Sets text elements associated with each (x,y,z) triplet. If a single string, the same string appears over all the data points. If an array of string, the items are mapped in order to the this trace's (x,y,z) coordinates.",
 );
@@ -108,16 +108,28 @@ Chart::Plotly::Trace::Scatter3d
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
-	use HTML::Show;
-	use Chart::Plotly;
-	use Chart::Plotly::Trace::Scatter3d;
-	my $scatter3d = Chart::Plotly::Trace::Scatter3d->new(x => [1 .. 5], y => [1 .. 5]);
-	
-	HTML::Show::show(Chart::Plotly::render_full_html(data => [$scatter3d]));
+ use Chart::Plotly qw(show_plot);
+ use Chart::Plotly::Trace::Scatter3d;
+ use English qw(-no_match_vars);
+ use Const::Fast;
+ 
+ const my $PI => 4 * atan2( 1, 1 );
+ const my $DELTA => 0.1;
+ my ( @x, @y, @z );
+ for ( my $u = 0; $u <= 2 * $PI; $u += $DELTA ) {
+     for ( my $v = -1; $v < 1; $v += $DELTA ) {
+         push @x, ( 1 + ( $v / 2 ) * cos( $u / 2 ) ) * cos($u);
+         push @y, ( 1 + ( $v / 2 ) * cos( $u / 2 ) ) * sin($u);
+         push @z, ( $v / 2 ) * sin( $u / 2 );
+     }
+ }
+ my $scatter3d = Chart::Plotly::Trace::Scatter3d->new( x => \@x, y => \@y, z => \@z, mode => 'lines' );
+ 
+ show_plot( [$scatter3d] );
 
 =head1 DESCRIPTION
 
