@@ -6,7 +6,7 @@ use Chart::Plotly::Trace::Attribute::Error_y;
 use Chart::Plotly::Trace::Attribute::Line;
 use Chart::Plotly::Trace::Attribute::Marker;
 
-our $VERSION = '0.009';    # VERSION
+our $VERSION = '0.010';    # VERSION
 
 sub TO_JSON {
     my $self = shift;
@@ -63,7 +63,7 @@ has mode => ( is            => 'rw',
 
 has text => (
     is  => 'rw',
-    isa => "Str",
+    isa => "Maybe[ArrayRef]|Str",
     documentation =>
       "Sets text elements associated with each (x,y) pair to appear on hover. If a single string, the same string appears over all the data points. If an array of string, the items are mapped in order to the this trace's (x,y) coordinates.",
 );
@@ -113,16 +113,29 @@ Chart::Plotly::Trace::Scattergl
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
-	use HTML::Show;
-	use Chart::Plotly;
-	use Chart::Plotly::Trace::Scattergl;
-	my $scattergl = Chart::Plotly::Trace::Scattergl->new(x => [1 .. 5], y => [1 .. 5]);
-	
-	HTML::Show::show(Chart::Plotly::render_full_html(data => [$scattergl]));
+ use Chart::Plotly qw(show_plot);
+ use Chart::Plotly::Trace::Scattergl;
+ use English qw(-no_match_vars);
+ 
+ my $scattergl = Chart::Plotly::Trace::Scattergl->new(
+     x => [
+         map {
+             2 * cos( $ARG * 2 * 3.14 / 100 ) +
+               cos( 2 * $ARG * 2 * 3.14 / 100 )
+         } ( 1 .. 101 )
+     ],
+     y => [
+         map {
+             2 * sin( $ARG * 2 * 3.14 / 100 ) + sin( 2 * $ARG * 2 * 3.14 / 100 )
+         } ( 1 .. 101 )
+     ]
+ );
+ 
+ show_plot( [$scattergl] );
 
 =head1 DESCRIPTION
 
