@@ -4,7 +4,7 @@ use Moose;
 use Chart::Plotly::Trace::Attribute::Line;
 use Chart::Plotly::Trace::Attribute::Marker;
 
-our $VERSION = '0.009';    # VERSION
+our $VERSION = '0.010';    # VERSION
 
 sub TO_JSON {
     my $self = shift;
@@ -85,7 +85,7 @@ has sum => (
 
 has text => (
     is  => 'rw',
-    isa => "Str",
+    isa => "Maybe[ArrayRef]|Str",
     documentation =>
       "Sets text elements associated with each (a,b,c) point. If a single string, the same string appears over all the data points. If an array of strings, the items are mapped in order to the the data points in (a,b,c).",
 );
@@ -123,16 +123,16 @@ Chart::Plotly::Trace::Scatterternary
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
-	use HTML::Show;
-	use Chart::Plotly;
-	use Chart::Plotly::Trace::Scatterternary;
-	my $scatterternary = Chart::Plotly::Trace::Scatterternary->new(x => [1 .. 5], y => [1 .. 5]);
-	
-	HTML::Show::show(Chart::Plotly::render_full_html(data => [$scatterternary]));
+ use HTML::Show;
+ use Chart::Plotly;
+ use Chart::Plotly::Trace::Scatterternary;
+ my $scatterternary = Chart::Plotly::Trace::Scatterternary->new( x => [ 1 .. 5 ], y => [ 1 .. 5 ] );
+ 
+ HTML::Show::show( Chart::Plotly::render_full_html( data => [$scatterternary] ) );
 
 =head1 DESCRIPTION
 
