@@ -6,7 +6,7 @@ use Chart::Plotly::Trace::Attribute::Contours;
 use Chart::Plotly::Trace::Attribute::Lighting;
 use Chart::Plotly::Trace::Attribute::Lightposition;
 
-our $VERSION = '0.009';    # VERSION
+our $VERSION = '0.010';    # VERSION
 
 sub TO_JSON {
     my $self = shift;
@@ -121,16 +121,26 @@ Chart::Plotly::Trace::Surface
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
-	use HTML::Show;
-	use Chart::Plotly;
-	use Chart::Plotly::Trace::Surface;
-	my $surface = Chart::Plotly::Trace::Surface->new(x => [1 .. 5], y => [1 .. 5]);
-	
-	HTML::Show::show(Chart::Plotly::render_full_html(data => [$surface]));
+ use Chart::Plotly qw(show_plot);
+ use Chart::Plotly::Trace::Surface;
+ use English qw(-no_match_vars);
+ 
+ my $surface = Chart::Plotly::Trace::Surface->new(
+     x => [ 0 .. 10 ],
+     y => [ 0 .. 10 ],
+     z => [
+         map {
+             my $y = $ARG;
+             [ map { $ARG - $y * $y } ( 0 .. 10 ) ]
+         } ( 0 .. 10 )
+     ]
+ );
+ 
+ show_plot( [$surface] );
 
 =head1 DESCRIPTION
 
